==> gtk-3.98.2.tar.xz: gtk-3.98.2/gdk/win32/gdkmonitor-win32.h <==
/*
 * Copyright © 2016 Red Hat, Inc
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GDK_WIN32_MONITOR_PRIVATE_H__
#define __GDK_WIN32_MONITOR_PRIVATE_H__

#include <windows.h>
#include <glib.h>
#include <gio/gio.h>

#include "gdkmonitorprivate.h"

#include "gdkwin32monitor.h"

struct _GdkWin32Monitor
{
  GdkMonitor parent;

  /* work area */
  GdkRectangle work_rect;

  /* Device instance path (used to match GdkWin32Monitor to monitor device) */
  gchar *instance_path;

  /* TRUE if monitor is made up by us
   * (this happens when system has logical monitors, but no physical ones).
   */
  guint madeup : 1;

  /* TRUE if we should notify GDK about this monitor being added */
  guint add    : 1;

  /* TRUE if we should notify GDK about this monitor being removed */
  guint remove : 1;
};

struct _GdkWin32MonitorClass {
  GdkMonitorClass parent_class;
};

int        _gdk_win32_monitor_compare  (GdkWin32Monitor *a, GdkWin32Monitor *b);

#endif

==> gtk-4.8.1.tar.xz: gtk-4.8.1/gdk/win32/gdkmonitor-win32.h <==
/*
 * Copyright © 2016 Red Hat, Inc
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GDK_WIN32_MONITOR_PRIVATE_H__
#define __GDK_WIN32_MONITOR_PRIVATE_H__

#include <windows.h>
#include <glib.h>
#include <gio/gio.h>

#include "gdkmonitorprivate.h"

#include "gdkwin32monitor.h"

struct _GdkWin32Monitor
{
  GdkMonitor parent;

  /* work area */
  GdkRectangle work_rect;

  /* Device instance path (used to match GdkWin32Monitor to monitor device) */
  char *instance_path;

  /* TRUE if monitor is made up by us
   * (this happens when system has logical monitors, but no physical ones).
   */
  guint madeup : 1;

  /* TRUE if we should notify GDK about this monitor being added */
  guint add    : 1;

  /* TRUE if we should notify GDK about this monitor being removed */
  guint remove : 1;
};

struct _GdkWin32MonitorClass {
  GdkMonitorClass parent_class;
};

int        _gdk_win32_monitor_compare  (GdkWin32Monitor *a, GdkWin32Monitor *b);

#endif
